package
Version:
v0.0.0-...-52d3920
Opens a new window with list of versions in this module.
Published: Feb 25, 2014
License: MIT
Opens a new window with license information.
Imports: 2
Opens a new window with list of imports.
Imported by: 0
Opens a new window with list of known importers.
Documentation
¶
type Checker interface {
Check() (Status, err)
}
type Monitor struct {
Conf map[string]interface{}
Check Checker
}
type StandardChecker struct {
URL string
Interval int32
}
SNMP
func (*StandardChecker) Check ¶
Source Files
¶
Click to show internal directories.
Click to hide internal directories.